![install and test](https://github.com/simonpf/weather_app_solution/workflows/install_and_test/badge.svg)

# The `weather_app` package

This repository provides a very simple Python package to access the SMHI weather forecast
API.

## Documentation

Online documentation can be found [here](https://simonpf.github.com/weather_app_solution).


